@@ -27,13 +27,13 @@ function(x, filename, options=NULL, format, prj=FALSE, ...) {
 #	} else if ( filetype == "big.matrix" ) { 
 #		x <- .startBigMatrixWriting(x, filename, ...)
 	} else {
-		x <- .startGDALwriting(x, filename, options=options, format=filetype, ...)
+		x <- .startGDALwriting(x, filename, gdal=options, format=filetype, ...)
 	}		
 	
 	if (prj) {
-		crs <-.getCRS(x)
-		if (crs != "") {
-			writeLines(wkt(x), extension(filename, "prj") )
+		wk <- wkt(x)
+		if (wk != "") {
+			writeLines(wk, extension(filename, "prj") )
 		}
 	}
 	return(x)
@@ -61,7 +61,7 @@ function(x, filename, options=NULL, format, prj=FALSE, ...) {
 #	} else if ( filetype == "big.matrix" ) { 
 #		x <- .startBigMatrixWriting(x, filename, ...)
 	} else {
-		x <- .startGDALwriting(x, filename, options=options, format=filetype, ...) 
+		x <- .startGDALwriting(x, filename, gdal=options, format=filetype, ...) 
 	}
 	
 	if (prj) {
